/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ITestObjectProvider } from "@fluidframework/test-utils";
import { ITestObjectProviderOptions } from "./describeCompat";
/**
 * Interface to hold the requested versions which should be installed
 * prior to running the test suite. The properties are cumulative, as all
 * versions deduced from all properties will be installed.
 */
export interface IRequestedFluidVersions {
    /**
     * Delta of versions to be installed with the current
     * package version as the baseline.
     */
    requestRelativeVersions?: number;
    /**
     * Array of specific versions to be installed
     */
    requestAbsoluteVersions?: string[];
}
declare type DescribeSuiteWithVersions = (name: string, tests: (this: Mocha.Suite, provider: (options?: ITestObjectProviderOptions) => ITestObjectProvider) => void) => Mocha.Suite | void;
declare type DescribeWithVersions = DescribeSuiteWithVersions & Record<"skip" | "only", DescribeSuiteWithVersions>;
/**
 * Creates a test suite which will priorly install a set of requested Fluid versions for the tests to use.
 * The packages are installed before any test code runs, so it is guaranteed that the package is present
 * when the test code is invoked, including the top level scope inside the `describeInstallVersions` block.
 *
 * If package installation fails for any of the requested versions, the test suite will not be created and
 * the test run will fail.
 *
 * @param requestedVersions - See {@link IRequestedFluidVersions}.
 * If unspecified, the test will install the last 2 versions.
 * @param timeoutMs - the timeout for the tests in milliseconds, as package installation is time consuming.
 * If unspecified, the timeout is 20000 ms.
 * @returns A mocha test suite
 */
export declare function describeInstallVersions(requestedVersions?: IRequestedFluidVersions, timeoutMs?: number): DescribeWithVersions;
export {};
//# sourceMappingURL=describeWithVersions.d.ts.map